#!/bin/sh
if [ ! -L dev/cdrom ]; then # provide a reasonable default
 ( cd dev ; ln -sf /dev/scd0 cdrom )
fi
if [ ! -L dev/modem ]; then # provide a reasonable default
 ( cd dev ; ln -sf  ttyS1 modem )
fi
if [ ! -L dev/mouse ]; then # provide a reasonable default
 ( cd dev ; ln -sf  psaux mouse )
fi
# just in case
chmod 666 dev/ptmx
# end just in case
( cd dev ; rm -rf core )
( cd dev ; ln -sf /proc/kcore core )
( cd dev ; rm -rf ftape )
( cd dev ; ln -sf rft0 ftape )
( cd dev ; rm -rf nftape )
( cd dev ; ln -sf nrft0 nftape )
( cd dev ; rm -rf X0R )
( cd dev ; ln -sf null X0R )
( cd dev ; rm -rf rmt0 )
( cd dev ; ln -sf st0 rmt0 )
( cd dev ; rm -rf rmt1 )
( cd dev ; ln -sf st1 rmt1 )
( cd dev ; rm -rf nrmt0 )
( cd dev ; ln -sf nst0 nrmt0 )
( cd dev ; rm -rf nrmt1 )
( cd dev ; ln -sf nst1 nrmt1 )
( cd dev ; rm -rf nfsd )
( cd dev ; ln -sf socksys nfsd )
( cd dev ; rm -rf systty )
( cd dev ; ln -sf console systty )
( cd dev ; rm -rf fd )
( cd dev ; ln -sf /proc/self/fd fd )
( cd dev ; rm -rf stdin )
( cd dev ; ln -sf fd/0 stdin )
( cd dev ; rm -rf stdout )
( cd dev ; ln -sf fd/1 stdout )
( cd dev ; rm -rf stderr )
( cd dev ; ln -sf fd/2 stderr )
( cd dev ; rm -rf js2 )
( cd dev ; ln -sf input/js2 js2 )
( cd dev ; rm -rf js0 )
( cd dev ; ln -sf input/js0 js0 )
( cd dev ; rm -rf js1 )
( cd dev ; ln -sf input/js1 js1 )
( cd dev ; rm -rf js3 )
( cd dev ; ln -sf input/js3 js3 )
( cd dev ; rm -rf video )
( cd dev ; ln -sf video0 video )
( cd dev ; rm -rf radio )
( cd dev ; ln -sf radio0 radio )
( cd dev ; rm -rf vbi )
( cd dev ; ln -sf vbi0 vbi )
( cd dev ; rm -rf dsp )
( cd dev ; ln -sf dsp0 dsp )
( cd dev ; rm -rf adsp )
( cd dev ; ln -sf adsp0 adsp )
( cd dev ; rm -rf midi )
( cd dev ; ln -sf midi00 midi )
( cd dev ; rm -rf amidi )
( cd dev ; ln -sf amidi0 amidi )
( cd dev ; rm -rf audio )
( cd dev ; ln -sf audio0 audio )
( cd dev ; rm -rf mixer )
( cd dev ; ln -sf mixer0 mixer )
( cd dev ; rm -rf sequencer2 )
( cd dev ; ln -sf music sequencer2 )
